pub struct MockOrganizationAuthRequestsApi {
OrganizationAuthRequestsApi_expectations: MockOrganizationAuthRequestsApi_OrganizationAuthRequestsApi,
}Fields
OrganizationAuthRequestsApi_expectations: MockOrganizationAuthRequestsApi_OrganizationAuthRequestsApiImplementations
Sourceimpl MockOrganizationAuthRequestsApi
impl MockOrganizationAuthRequestsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationAuthRequestsApi
impl MockOrganizationAuthRequestsApi
Sourcepub fn expect_bulk_deny_requests(&mut self) -> &mut Expectation
pub fn expect_bulk_deny_requests(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_deny_requests method
Sourcepub fn expect_get_pending_requests(&mut self) -> &mut Expectation
pub fn expect_get_pending_requests(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_pending_requests method
Sourcepub fn expect_update_auth_request(&mut self) -> &mut Expectation
pub fn expect_update_auth_request(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_auth_request method
Sourcepub fn expect_update_many_auth_requests(&mut self) -> &mut Expectation
pub fn expect_update_many_auth_requests(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_many_auth_requests method